@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 #----------------------------------------------------------------------------
 
@@ -87,7 +87,8 @@ sub get_info {
         $data = $self->{driver}->get_info();
     };
 
-    return  if($@);
+    $data->{error} = $@ if($@);
+
     return $data;
 }
 
@@ -180,9 +181,9 @@ RT Queue: http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2010-2012 Birmingham Perl Mongers
+  Copyright (C) 2010-2014 Birmingham Perl Mongers
 
-  This module is free software; you can redistribute it and/or
+  This distribution is free software; you can redistribute it and/or
   modify it under the Artistic License 2.0.
 
 =cut
