@@ -82,6 +82,7 @@ sub _macos_versions {
         '10.6' => 'Snow Leopard',
         '10.7' => 'Lion',
         '10.8' => 'Mountain Lion',
+        '10.9' => 'Mavericks',
     };
 }
 
@@ -158,9 +159,9 @@ RT Queue: http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2010-2012 Birmingham Perl Mongers
+  Copyright (C) 2010-2014 Birmingham Perl Mongers
 
-  This module is free software; you can redistribute it and/or
+  This distribution is free software; you can redistribute it and/or
   modify it under the Artistic License 2.0.
 
 =cut
